package cz.jzitnik.game.logic.services.flowing.water;

import cz.jzitnik.game.Game;
import cz.jzitnik.game.annotations.CustomLogic;
import cz.jzitnik.game.entities.Block;
import cz.jzitnik.game.entities.items.ItemBlockSupplier;
import cz.jzitnik.game.logic.CustomLogicInterface;
import cz.jzitnik.game.sprites.Water;
import lombok.AllArgsConstructor;
import lombok.Getter;

import java.awt.*;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

@CustomLogic
public class WaterLogic implements CustomLogicInterface {
    private static final int RADIUS = 20;

    @AllArgsConstructor
    @Getter
    private static class WaterBlock {
        private Block block;
        private int x;
        private int y;
    }

    @Override
    public void nextIteration(Game game) {
        int[] data = game.getPlayerCords();
        var world = game.getWorld();
        int playerX = data[0];
        int playerY = data[1];

        int startX = Math.max(0, playerX - RADIUS);
        int startY = Math.max(0, playerY - RADIUS);
        int endX = Math.min(world[0].length - 1, playerX + RADIUS);
        int endY = Math.min(world.length - 1, playerY + RADIUS);

        List<WaterBlock> sourceBlocks = new ArrayList<>();

        for (int y = startY; y <= endY; y++) {
            for (int x = startX; x <= endX; x++) {
                var blocks = world[y][x];

                var waterSourceBlocks = blocks.stream()
                        .filter(block -> block.getBlockId().equals("water") && ((WaterData) block.getData()).isSource())
                        .toList();
                if (!waterSourceBlocks.isEmpty()) {
                    sourceBlocks.add(new WaterBlock(waterSourceBlocks.getFirst(), x, y));
                }

                world[y][x].removeAll(blocks.stream()
                        .filter(i -> i.getBlockId().equals("water") && !((WaterData) i.getData()).isSource()).toList());
            }
        }

        for (WaterBlock sourceBlock : sourceBlocks) {
            int x = sourceBlock.getX();
            int y = sourceBlock.getY();

            flow(world, x, y, 5, new HashSet<>());
        }
    }

    public void flow(List<Block>[][] world, int x, int y, int strength, Set<Point> visited) {
        if (y + 1 < world.length && waterCanFlow(world[y + 1][x])) {
            Block newWater = ItemBlockSupplier.getBlock("water");
            newWater.setSpriteState(Water.WaterState.get(5));
            ((WaterData) newWater.getData()).setSource(false);
            world[y + 1][x].add(newWater);
            flow(world, x, y + 1, 5, visited);
            return;
        }

        if (strength == 1 || visited.contains(new Point(x, y))) {
            return;
        }
        visited.add(new Point(x, y));

        if (x - 1 >= 0 && waterCanFlow(world[y][x - 1])) {
            Block newWater = ItemBlockSupplier.getBlock("water");
            newWater.setSpriteState(Water.WaterState.get(strength - 1));
            ((WaterData) newWater.getData()).setSource(false);
            world[y][x - 1].add(newWater);
            flow(world, x - 1, y, strength - 1, visited);
        }

        if (x + 1 < world[y].length && waterCanFlow(world[y][x + 1])) {
            Block newWater = ItemBlockSupplier.getBlock("water");
            newWater.setSpriteState(Water.WaterState.get(strength - 1));
            ((WaterData) newWater.getData()).setSource(false);
            world[y][x + 1].add(newWater);
            flow(world, x + 1, y, strength - 1, visited);
        }
    }

    private boolean waterCanFlow(List<Block> blocks) {
        return blocks.stream().allMatch(
                block -> block.getBlockId().equals("steve") || block.getBlockId().equals("air") || block.isMob());
    }
}
